@@ -142,6 +142,23 @@ def test_database_names_to_dump_passes_through_name():
     assert names == ('foo',)
 
 
+def test_database_names_to_dump_with_non_all_name_and_skip_names_warns():
+    environment = flexmock()
+
+    flexmock(module.logger).should_receive('warning').once()
+
+    names = module.database_names_to_dump(
+        {'name': 'foo', 'skip_names': ('foo', 'bar')},
+        {},
+        'root',
+        'trustsome1',
+        environment,
+        dry_run=False,
+    )
+
+    assert names == ('foo',)
+
+
 def test_database_names_to_dump_bails_for_dry_run():
     environment = flexmock()
     flexmock(module).should_receive('execute_command_and_capture_output').never()
@@ -169,6 +186,9 @@ def test_database_names_to_dump_queries_mariadb_for_database_names():
         'trustsome1',
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        '/path/to/working/dir'
+    )
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mariadb',
@@ -179,6 +199,7 @@ def test_database_names_to_dump_queries_mariadb_for_database_names():
             'show schemas',
         ),
         environment=environment,
+        working_directory='/path/to/working/dir',
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -193,6 +214,43 @@ def test_database_names_to_dump_queries_mariadb_for_database_names():
     assert names == ('foo', 'bar')
 
 
+def test_database_names_to_dump_with_database_name_all_and_skip_names_filters_out_unwanted_databases():
+    environment = flexmock()
+    flexmock(module.borgmatic.hooks.credential.parse).should_receive(
+        'resolve_credential',
+    ).replace_with(lambda value, config: value)
+    flexmock(module).should_receive('parse_extra_options').and_return((), None)
+    flexmock(module).should_receive('make_defaults_file_options').with_args(
+        'root',
+        'trustsome1',
+        None,
+    ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command_and_capture_output').with_args(
+        (
+            'mariadb',
+            '--defaults-extra-file=/dev/fd/99',
+            '--skip-column-names',
+            '--batch',
+            '--execute',
+            'show schemas',
+        ),
+        environment=environment,
+        working_directory=None,
+    ).and_return('foo\nbar\nbaz\nmysql\n').once()
+
+    names = module.database_names_to_dump(
+        {'name': 'all', 'skip_names': ('foo', 'bar')},
+        {},
+        'root',
+        'trustsome1',
+        environment,
+        dry_run=False,
+    )
+
+    assert names == ('baz',)
+
+
 def test_database_names_to_dump_with_environment_password_transport_skips_defaults_file_and_passes_user_flag():
     environment = flexmock()
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
@@ -200,6 +258,7 @@ def test_database_names_to_dump_with_environment_password_transport_skips_defaul
     ).replace_with(lambda value, config: value)
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
     flexmock(module).should_receive('make_defaults_file_options').never()
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mariadb',
@@ -211,6 +270,7 @@ def test_database_names_to_dump_with_environment_password_transport_skips_defaul
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -236,6 +296,7 @@ def test_database_names_to_dump_runs_mariadb_with_tls():
         'trustsome1',
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mariadb',
@@ -247,6 +308,7 @@ def test_database_names_to_dump_runs_mariadb_with_tls():
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -272,6 +334,7 @@ def test_database_names_to_dump_runs_mariadb_without_tls():
         'trustsome1',
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mariadb',
@@ -283,6 +346,7 @@ def test_database_names_to_dump_runs_mariadb_without_tls():
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -357,6 +421,13 @@ def test_dump_data_sources_dumps_each_database():
             module.borgmatic.actions.restore.Dump('mariadb_databases', 'bar'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mariadb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -406,6 +477,13 @@ def test_dump_data_sources_dumps_with_password():
             module.borgmatic.actions.restore.Dump('mariadb_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mariadb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         [database],
@@ -457,6 +535,13 @@ def test_dump_data_sources_dumps_with_environment_password_transport_passes_pass
             module.borgmatic.actions.restore.Dump('mariadb_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mariadb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         [database],
@@ -495,6 +580,13 @@ def test_dump_data_sources_dumps_all_databases_at_once():
             module.borgmatic.actions.restore.Dump('mariadb_databases', 'all'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mariadb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -537,6 +629,13 @@ def test_dump_data_sources_dumps_all_databases_separately_when_format_configured
             module.borgmatic.actions.restore.Dump('mariadb_databases', 'bar'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mariadb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -562,6 +661,7 @@ def test_dump_data_sources_errors_for_missing_all_databases():
         'databases/localhost/all',
     )
     flexmock(module).should_receive('database_names_to_dump').and_return(())
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     with pytest.raises(ValueError):
         assert module.dump_data_sources(
@@ -585,6 +685,7 @@ def test_dump_data_sources_does_not_error_for_missing_all_databases_with_dry_run
         'databases/localhost/all',
     )
     flexmock(module).should_receive('database_names_to_dump').and_return(())
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     assert (
         module.dump_data_sources(
@@ -610,6 +711,7 @@ def test_database_names_to_dump_runs_mariadb_with_list_options():
         'trustsome1',
         'mariadb.cnf',
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mariadb',
@@ -621,6 +723,7 @@ def test_database_names_to_dump_runs_mariadb_with_list_options():
             'show schemas',
         ),
         environment=None,
+        working_directory=None,
     ).and_return('foo\nbar').once()
 
     assert module.database_names_to_dump(database, {}, 'root', 'trustsome1', None, '') == (
@@ -644,6 +747,7 @@ def test_database_names_to_dump_runs_non_default_mariadb_with_list_options():
         'trustsome1',
         'mariadb.cnf',
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         environment=None,
         full_command=(
@@ -655,6 +759,7 @@ def test_database_names_to_dump_runs_non_default_mariadb_with_list_options():
             '--execute',
             'show schemas',
         ),
+        working_directory=None,
     ).and_return('foo\nbar').once()
 
     assert module.database_names_to_dump(database, {}, 'root', 'trustsome1', None, '') == (
@@ -677,6 +782,7 @@ def test_execute_dump_command_runs_mariadb_dump():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -690,6 +796,7 @@ def test_execute_dump_command_runs_mariadb_dump():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -718,6 +825,7 @@ def test_execute_dump_command_with_environment_password_transport_skips_defaults
     flexmock(module).should_receive('parse_extra_options').and_return((), None)
     flexmock(module).should_receive('make_defaults_file_options').never()
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -732,6 +840,7 @@ def test_execute_dump_command_with_environment_password_transport_skips_defaults
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -764,6 +873,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_add_drop_database():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -776,6 +886,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_add_drop_database():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -808,6 +919,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_hostname_and_port():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -827,6 +939,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_hostname_and_port():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -859,6 +972,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_tls():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -873,6 +987,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_tls():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -905,6 +1020,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_tls():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -919,6 +1035,7 @@ def test_execute_dump_command_runs_mariadb_dump_without_tls():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -951,6 +1068,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_username_and_password():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -964,6 +1082,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_username_and_password():
         ),
         environment={},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -996,6 +1115,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_options():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1010,6 +1130,7 @@ def test_execute_dump_command_runs_mariadb_dump_with_options():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -1042,6 +1163,7 @@ def test_execute_dump_command_runs_non_default_mariadb_dump_with_options():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1056,6 +1178,7 @@ def test_execute_dump_command_runs_non_default_mariadb_dump_with_options():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -1152,12 +1275,14 @@ def test_restore_data_source_dump_runs_mariadb_to_restore():
         None,
     ).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mariadb', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1190,12 +1315,14 @@ def test_restore_data_source_dump_runs_mariadb_with_options():
         None,
     ).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mariadb', '--harder', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1230,12 +1357,14 @@ def test_restore_data_source_dump_runs_non_default_mariadb_with_options():
         None,
     ).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('custom_mariadb', '--harder', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1268,6 +1397,7 @@ def test_restore_data_source_dump_runs_mariadb_with_hostname_and_port():
         None,
     ).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mariadb',
@@ -1283,6 +1413,7 @@ def test_restore_data_source_dump_runs_mariadb_with_hostname_and_port():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1315,6 +1446,7 @@ def test_restore_data_source_dump_runs_mariadb_with_tls():
         None,
     ).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mariadb',
@@ -1325,6 +1457,7 @@ def test_restore_data_source_dump_runs_mariadb_with_tls():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1357,6 +1490,7 @@ def test_restore_data_source_dump_runs_mariadb_without_tls():
         None,
     ).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mariadb',
@@ -1367,6 +1501,7 @@ def test_restore_data_source_dump_runs_mariadb_without_tls():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1399,12 +1534,14 @@ def test_restore_data_source_dump_runs_mariadb_with_username_and_password():
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mariadb', '--defaults-extra-file=/dev/fd/99', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1442,12 +1579,14 @@ def test_restore_data_source_with_environment_password_transport_skips_defaults_
     flexmock(module.os).should_receive('environ').and_return(
         {'USER': 'root', 'MYSQL_PWD': 'trustsome1'},
     )
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mariadb', '--batch', '--user', 'root'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root', 'MYSQL_PWD': 'trustsome1'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1490,6 +1629,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mariadb',
@@ -1506,6 +1646,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1552,6 +1693,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mariadb',
@@ -1569,6 +1711,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
