@@ -31,12 +31,16 @@ def test_dump_data_sources_runs_mongodump_for_each_database():
         'databases/localhost/foo',
     ).and_return('databases/localhost/bar')
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        '/path/to/working/dir'
+    )
 
     for name, process in zip(('foo', 'bar'), processes):
         flexmock(module).should_receive('execute_command').with_args(
             ('mongodump', '--db', name, '--archive', '>', f'databases/localhost/{name}'),
             shell=True,
             run_to_completion=False,
+            working_directory='/path/to/working/dir',
         ).and_return(process).once()
 
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
@@ -47,6 +51,13 @@ def test_dump_data_sources_runs_mongodump_for_each_database():
             module.borgmatic.actions.restore.Dump('mongodb_databases', 'bar'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mongodb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -70,6 +81,7 @@ def test_dump_data_sources_with_dry_run_skips_mongodump():
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
     flexmock(module).should_receive('execute_command').never()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').never()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     assert (
         module.dump_data_sources(
@@ -92,6 +104,7 @@ def test_dump_data_sources_runs_mongodump_with_hostname_and_port():
         'databases/database.example.org/foo',
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -108,6 +121,7 @@ def test_dump_data_sources_runs_mongodump_with_hostname_and_port():
         ),
         shell=True,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -118,6 +132,13 @@ def test_dump_data_sources_runs_mongodump_with_hostname_and_port():
             ),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mongodb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -150,6 +171,7 @@ def test_dump_data_sources_runs_mongodump_with_username_and_password():
         '/dev/fd/99',
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -168,6 +190,7 @@ def test_dump_data_sources_runs_mongodump_with_username_and_password():
         ),
         shell=True,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -176,6 +199,13 @@ def test_dump_data_sources_runs_mongodump_with_username_and_password():
             module.borgmatic.actions.restore.Dump('mongodb_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mongodb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -195,10 +225,12 @@ def test_dump_data_sources_runs_mongodump_with_directory_format():
     )
     flexmock(module.dump).should_receive('create_parent_directory_for_dump')
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         ('mongodump', '--out', 'databases/localhost/foo', '--db', 'foo'),
         shell=True,
+        working_directory=None,
     ).and_return(flexmock()).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -207,6 +239,13 @@ def test_dump_data_sources_runs_mongodump_with_directory_format():
             module.borgmatic.actions.restore.Dump('mongodb_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mongodb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -229,6 +268,7 @@ def test_dump_data_sources_runs_mongodump_with_options():
         'databases/localhost/foo',
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -242,6 +282,7 @@ def test_dump_data_sources_runs_mongodump_with_options():
         ),
         shell=True,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -250,6 +291,13 @@ def test_dump_data_sources_runs_mongodump_with_options():
             module.borgmatic.actions.restore.Dump('mongodb_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mongodb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -269,11 +317,13 @@ def test_dump_data_sources_runs_mongodumpall_for_all_databases():
         'databases/localhost/all',
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         ('mongodump', '--archive', '>', 'databases/localhost/all'),
         shell=True,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -282,6 +332,13 @@ def test_dump_data_sources_runs_mongodumpall_for_all_databases():
             module.borgmatic.actions.restore.Dump('mongodb_databases', 'all'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mongodb_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -330,11 +387,13 @@ def test_restore_data_source_dump_runs_mongorestore():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ['mongorestore', '--archive', '--drop'],
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -364,6 +423,7 @@ def test_restore_data_source_dump_runs_mongorestore_with_hostname_and_port():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
@@ -377,6 +437,7 @@ def test_restore_data_source_dump_runs_mongorestore_with_hostname_and_port():
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -415,6 +476,7 @@ def test_restore_data_source_dump_runs_mongorestore_with_username_and_password()
     flexmock(module).should_receive('make_password_config_file').with_args('trustsome1').and_return(
         '/dev/fd/99',
     )
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
@@ -430,6 +492,7 @@ def test_restore_data_source_dump_runs_mongorestore_with_username_and_password()
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -472,6 +535,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
     flexmock(module).should_receive('make_password_config_file').with_args(
         'clipassword',
     ).and_return('/dev/fd/99')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
@@ -491,6 +555,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -533,6 +598,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
     flexmock(module).should_receive('make_password_config_file').with_args(
         'restorepass',
     ).and_return('/dev/fd/99')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
@@ -552,6 +618,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -579,11 +646,13 @@ def test_restore_data_source_dump_runs_mongorestore_with_options():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ['mongorestore', '--archive', '--drop', '--harder'],
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -611,6 +680,7 @@ def test_restore_databases_dump_runs_mongorestore_with_schemas():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
@@ -624,6 +694,7 @@ def test_restore_databases_dump_runs_mongorestore_with_schemas():
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -651,11 +722,13 @@ def test_restore_data_source_dump_runs_psql_for_all_database_dump():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ['mongorestore', '--archive'],
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -708,11 +781,13 @@ def test_restore_data_source_dump_without_extract_process_restores_from_disk():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ['mongorestore', '--dir', '/dump/path', '--drop'],
         processes=[],
         output_log_level=logging.DEBUG,
         input_file=None,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -742,6 +817,7 @@ def test_dump_data_sources_uses_custom_mongodump_command():
         'databases/localhost/foo',
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -754,6 +830,7 @@ def test_dump_data_sources_uses_custom_mongodump_command():
         ),
         shell=True,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -812,6 +889,7 @@ def test_restore_data_source_dump_uses_custom_mongorestore_command():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'custom_mongorestore',  # Should use custom command instead of default
@@ -822,6 +900,7 @@ def test_restore_data_source_dump_uses_custom_mongorestore_command():
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
