@@ -68,6 +68,7 @@ def test_database_names_to_dump_queries_mysql_for_database_names():
     flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mysql',
@@ -78,6 +79,7 @@ def test_database_names_to_dump_queries_mysql_for_database_names():
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -107,6 +109,7 @@ def test_database_names_to_dump_with_database_name_all_and_skip_names_filters_ou
         'trustsome1',
         None,
     ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mysql',
@@ -117,6 +120,7 @@ def test_database_names_to_dump_with_database_name_all_and_skip_names_filters_ou
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nbaz\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -142,6 +146,7 @@ def test_database_names_to_dump_with_environment_password_transport_skips_defaul
     flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
         'make_defaults_file_options',
     ).never()
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mysql',
@@ -153,6 +158,7 @@ def test_database_names_to_dump_with_environment_password_transport_skips_defaul
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -178,6 +184,7 @@ def test_database_names_to_dump_runs_mysql_with_tls():
     flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mysql',
@@ -189,6 +196,7 @@ def test_database_names_to_dump_runs_mysql_with_tls():
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -214,6 +222,7 @@ def test_database_names_to_dump_runs_mysql_without_tls():
     flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mysql',
@@ -225,6 +234,7 @@ def test_database_names_to_dump_runs_mysql_without_tls():
             'show schemas',
         ),
         environment=environment,
+        working_directory=None,
     ).and_return('foo\nbar\nmysql\n').once()
 
     names = module.database_names_to_dump(
@@ -584,6 +594,7 @@ def test_database_names_to_dump_runs_mysql_with_list_options():
     flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', 'my.cnf').and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'mysql',
@@ -595,6 +606,7 @@ def test_database_names_to_dump_runs_mysql_with_list_options():
             'show schemas',
         ),
         environment=None,
+        working_directory=None,
     ).and_return('foo\nbar').once()
 
     assert module.database_names_to_dump(database, {}, 'root', 'trustsome1', None, '') == (
@@ -615,6 +627,7 @@ def test_database_names_to_dump_runs_non_default_mysql_with_list_options():
     flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', 'my.cnf').and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         environment=None,
         full_command=(
@@ -626,6 +639,7 @@ def test_database_names_to_dump_runs_non_default_mysql_with_list_options():
             '--execute',
             'show schemas',
         ),
+        working_directory=None,
     ).and_return('foo\nbar').once()
 
     assert module.database_names_to_dump(database, {}, 'root', 'trustsome1', None, '') == (
@@ -648,6 +662,7 @@ def test_execute_dump_command_runs_mysqldump():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -661,6 +676,7 @@ def test_execute_dump_command_runs_mysqldump():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -693,6 +709,7 @@ def test_execute_dump_command_with_environment_password_transport_skips_defaults
         'make_defaults_file_options',
     ).never()
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -707,6 +724,7 @@ def test_execute_dump_command_with_environment_password_transport_skips_defaults
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -739,6 +757,7 @@ def test_execute_dump_command_runs_mysqldump_without_add_drop_database():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -751,6 +770,7 @@ def test_execute_dump_command_runs_mysqldump_without_add_drop_database():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -783,6 +803,7 @@ def test_execute_dump_command_runs_mysqldump_with_hostname_and_port():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -802,6 +823,7 @@ def test_execute_dump_command_runs_mysqldump_with_hostname_and_port():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -834,6 +856,7 @@ def test_execute_dump_command_runs_mysqldump_with_tls():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -848,6 +871,7 @@ def test_execute_dump_command_runs_mysqldump_with_tls():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -880,6 +904,7 @@ def test_execute_dump_command_runs_mysqldump_without_tls():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -894,6 +919,7 @@ def test_execute_dump_command_runs_mysqldump_without_tls():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -926,6 +952,7 @@ def test_execute_dump_command_runs_mysqldump_with_username_and_password():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -939,6 +966,7 @@ def test_execute_dump_command_runs_mysqldump_with_username_and_password():
         ),
         environment={},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -971,6 +999,7 @@ def test_execute_dump_command_runs_mysqldump_with_options():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -985,6 +1014,7 @@ def test_execute_dump_command_runs_mysqldump_with_options():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -1017,6 +1047,7 @@ def test_execute_dump_command_runs_non_default_mysqldump():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1030,6 +1061,7 @@ def test_execute_dump_command_runs_non_default_mysqldump():
         ),
         environment=None,
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
 
     assert (
@@ -1125,12 +1157,14 @@ def test_restore_data_source_dump_runs_mysql_to_restore():
         'make_defaults_file_options',
     ).with_args(None, None, None).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mysql', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1163,12 +1197,14 @@ def test_restore_data_source_dump_runs_mysql_with_options():
         'make_defaults_file_options',
     ).with_args(None, None, None).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mysql', '--harder', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1201,12 +1237,14 @@ def test_restore_data_source_dump_runs_non_default_mysql_with_options():
         'make_defaults_file_options',
     ).with_args(None, None, None).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('custom_mysql', '--harder', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1239,6 +1277,7 @@ def test_restore_data_source_dump_runs_mysql_with_hostname_and_port():
         'make_defaults_file_options',
     ).with_args(None, None, None).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mysql',
@@ -1254,6 +1293,7 @@ def test_restore_data_source_dump_runs_mysql_with_hostname_and_port():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1286,6 +1326,7 @@ def test_restore_data_source_dump_runs_mysql_with_tls():
         'make_defaults_file_options',
     ).with_args(None, None, None).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mysql',
@@ -1296,6 +1337,7 @@ def test_restore_data_source_dump_runs_mysql_with_tls():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1328,6 +1370,7 @@ def test_restore_data_source_dump_runs_mysql_without_tls():
         'make_defaults_file_options',
     ).with_args(None, None, None).and_return(())
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mysql',
@@ -1338,6 +1381,7 @@ def test_restore_data_source_dump_runs_mysql_without_tls():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1370,12 +1414,14 @@ def test_restore_data_source_dump_runs_mysql_with_username_and_password():
         'make_defaults_file_options',
     ).with_args('root', 'trustsome1', None).and_return(('--defaults-extra-file=/dev/fd/99',))
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mysql', '--defaults-extra-file=/dev/fd/99', '--batch'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1417,12 +1463,14 @@ def test_restore_data_source_with_environment_password_transport_skips_defaults_
     flexmock(module.os).should_receive('environ').and_return(
         {'USER': 'root', 'MYSQL_PWD': 'trustsome1'},
     )
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('mysql', '--batch', '--user', 'root'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root', 'MYSQL_PWD': 'trustsome1'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1467,6 +1515,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         ('--defaults-extra-file=/dev/fd/99',),
     )
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mysql',
@@ -1483,6 +1532,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1531,6 +1581,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         ('--defaults-extra-file=/dev/fd/99',),
     )
     flexmock(module.os).should_receive('environ').and_return({'USER': 'root'})
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'mysql',
@@ -1548,6 +1599,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'USER': 'root'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
