@@ -117,6 +117,9 @@ def test_database_names_to_dump_with_all_and_format_lists_databases_with_hostnam
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        '/path/to/working/dir'
+    )
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'psql',
@@ -131,6 +134,7 @@ def test_database_names_to_dump_with_all_and_format_lists_databases_with_hostnam
             '1234',
         ),
         environment=object,
+        working_directory='/path/to/working/dir',
     ).and_return('foo,test,\nbar,test,"stuff and such"')
 
     assert module.database_names_to_dump(database, {}, flexmock(), dry_run=False) == (
@@ -144,6 +148,7 @@ def test_database_names_to_dump_with_all_and_format_lists_databases_with_usernam
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'psql',
@@ -156,6 +161,7 @@ def test_database_names_to_dump_with_all_and_format_lists_databases_with_usernam
             'postgres',
         ),
         environment=object,
+        working_directory=None,
     ).and_return('foo,test,\nbar,test,"stuff and such"')
 
     assert module.database_names_to_dump(database, {}, flexmock(), dry_run=False) == (
@@ -169,9 +175,11 @@ def test_database_names_to_dump_with_all_and_format_lists_databases_with_options
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         ('psql', '--list', '--no-password', '--no-psqlrc', '--csv', '--tuples-only', '--harder'),
         environment=object,
+        working_directory=None,
     ).and_return('foo,test,\nbar,test,"stuff and such"')
 
     assert module.database_names_to_dump(database, {}, flexmock(), dry_run=False) == (
@@ -201,6 +209,7 @@ def test_database_names_to_dump_with_all_and_psql_command_uses_custom_command():
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
         'resolve_credential',
     ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         (
             'docker',
@@ -216,6 +225,7 @@ def test_database_names_to_dump_with_all_and_psql_command_uses_custom_command():
             '--tuples-only',
         ),
         environment=object,
+        working_directory=None,
     ).and_return('foo,text').once()
 
     assert module.database_names_to_dump(database, {}, flexmock(), dry_run=False) == ('foo',)
@@ -255,6 +265,7 @@ def test_dump_data_sources_runs_pg_dump_for_each_database():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     for name, process in zip(('foo', 'bar'), processes):
         flexmock(module).should_receive('execute_command').with_args(
@@ -272,6 +283,7 @@ def test_dump_data_sources_runs_pg_dump_for_each_database():
             shell=True,
             environment={'PGSSLMODE': 'disable'},
             run_to_completion=False,
+            working_directory=None,
         ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -281,6 +293,13 @@ def test_dump_data_sources_runs_pg_dump_for_each_database():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'bar'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -300,6 +319,7 @@ def test_dump_data_sources_raises_when_no_database_names_to_dump():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path').and_return('')
     flexmock(module).should_receive('database_names_to_dump').and_return(())
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     with pytest.raises(ValueError):
         module.dump_data_sources(
@@ -317,6 +337,7 @@ def test_dump_data_sources_does_not_raise_when_no_database_names_to_dump():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path').and_return('')
     flexmock(module).should_receive('database_names_to_dump').and_return(())
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     assert (
         module.dump_data_sources(
@@ -352,6 +373,13 @@ def test_dump_data_sources_with_duplicate_dump_skips_pg_dump():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'bar'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -383,6 +411,7 @@ def test_dump_data_sources_with_dry_run_skips_pg_dump():
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
     flexmock(module).should_receive('execute_command').never()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').never()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     assert (
         module.dump_data_sources(
@@ -411,6 +440,7 @@ def test_dump_data_sources_runs_pg_dump_with_hostname_and_port():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -431,6 +461,7 @@ def test_dump_data_sources_runs_pg_dump_with_hostname_and_port():
         shell=True,
         environment={'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -441,6 +472,13 @@ def test_dump_data_sources_runs_pg_dump_with_hostname_and_port():
             ),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -468,6 +506,7 @@ def test_dump_data_sources_runs_pg_dump_with_username_and_password():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -486,6 +525,7 @@ def test_dump_data_sources_runs_pg_dump_with_username_and_password():
         shell=True,
         environment={'PGPASSWORD': 'trustsome1', 'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -494,6 +534,13 @@ def test_dump_data_sources_runs_pg_dump_with_username_and_password():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -521,6 +568,7 @@ def test_dump_data_sources_with_username_injection_attack_gets_escaped():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -539,6 +587,7 @@ def test_dump_data_sources_with_username_injection_attack_gets_escaped():
         shell=True,
         environment={'PGPASSWORD': 'trustsome1', 'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -547,6 +596,13 @@ def test_dump_data_sources_with_username_injection_attack_gets_escaped():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -572,6 +628,7 @@ def test_dump_data_sources_runs_pg_dump_with_directory_format():
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_parent_directory_for_dump')
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -587,6 +644,7 @@ def test_dump_data_sources_runs_pg_dump_with_directory_format():
         ),
         shell=True,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).and_return(flexmock()).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -595,6 +653,13 @@ def test_dump_data_sources_runs_pg_dump_with_directory_format():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -623,6 +688,7 @@ def test_dump_data_sources_runs_pg_dump_with_string_compression():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -641,6 +707,7 @@ def test_dump_data_sources_runs_pg_dump_with_string_compression():
         shell=True,
         environment={'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(processes[0]).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -649,6 +716,13 @@ def test_dump_data_sources_runs_pg_dump_with_string_compression():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -677,6 +751,7 @@ def test_dump_data_sources_runs_pg_dump_with_integer_compression():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -695,6 +770,7 @@ def test_dump_data_sources_runs_pg_dump_with_integer_compression():
         shell=True,
         environment={'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(processes[0]).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -703,6 +779,13 @@ def test_dump_data_sources_runs_pg_dump_with_integer_compression():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -731,6 +814,7 @@ def test_dump_data_sources_runs_pg_dump_with_options():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -748,6 +832,7 @@ def test_dump_data_sources_runs_pg_dump_with_options():
         shell=True,
         environment={'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -756,6 +841,13 @@ def test_dump_data_sources_runs_pg_dump_with_options():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -781,12 +873,14 @@ def test_dump_data_sources_runs_pg_dumpall_for_all_databases():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         ('pg_dumpall', '--no-password', '--clean', '--if-exists', '>', 'databases/localhost/all'),
         shell=True,
         environment={'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -795,6 +889,13 @@ def test_dump_data_sources_runs_pg_dumpall_for_all_databases():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'all'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -820,6 +921,7 @@ def test_dump_data_sources_runs_non_default_pg_dump():
         'resolve_credential',
     ).replace_with(lambda value, config: value)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
 
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -838,6 +940,7 @@ def test_dump_data_sources_runs_non_default_pg_dump():
         shell=True,
         environment={'PGSSLMODE': 'disable'},
         run_to_completion=False,
+        working_directory=None,
     ).and_return(process).once()
     flexmock(module.dump).should_receive('write_data_source_dumps_metadata').with_args(
         '/run/borgmatic',
@@ -846,6 +949,13 @@ def test_dump_data_sources_runs_non_default_pg_dump():
             module.borgmatic.actions.restore.Dump('postgresql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/postgresql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -867,6 +977,7 @@ def test_restore_data_source_dump_runs_pg_restore():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -881,6 +992,7 @@ def test_restore_data_source_dump_runs_pg_restore():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -894,6 +1006,7 @@ def test_restore_data_source_dump_runs_pg_restore():
             'ANALYZE',
         ),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -924,6 +1037,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_hostname_and_port():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -942,6 +1056,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_hostname_and_port():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -959,6 +1074,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_hostname_and_port():
             'ANALYZE',
         ),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -991,6 +1107,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_username_and_password():
     )
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -1007,6 +1124,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_username_and_password():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGPASSWORD': 'trustsome1', 'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1022,6 +1140,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_username_and_password():
             'ANALYZE',
         ),
         environment={'PGPASSWORD': 'trustsome1', 'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1065,6 +1184,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
     )
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -1085,6 +1205,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGPASSWORD': 'clipassword', 'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1104,6 +1225,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
             'ANALYZE',
         ),
         environment={'PGPASSWORD': 'clipassword', 'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1147,6 +1269,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
     )
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -1167,6 +1290,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGPASSWORD': 'restorepassword', 'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1186,6 +1310,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
             'ANALYZE',
         ),
         environment={'PGPASSWORD': 'restorepassword', 'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1221,6 +1346,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_options():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -1236,6 +1362,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_options():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1250,6 +1377,7 @@ def test_restore_data_source_dump_runs_pg_restore_with_options():
             'ANALYZE',
         ),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1278,6 +1406,7 @@ def test_restore_data_source_dump_runs_psql_for_all_database_dump():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'psql',
@@ -1288,10 +1417,12 @@ def test_restore_data_source_dump_runs_psql_for_all_database_dump():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         ('psql', '--no-password', '--no-psqlrc', '--quiet', '--command', 'ANALYZE'),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1320,12 +1451,14 @@ def test_restore_data_source_dump_runs_psql_for_plain_database_dump():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ('psql', '--no-password', '--no-psqlrc', '--dbname', 'foo'),
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1339,6 +1472,7 @@ def test_restore_data_source_dump_runs_psql_for_plain_database_dump():
             'ANALYZE',
         ),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1374,6 +1508,7 @@ def test_restore_data_source_dump_runs_non_default_pg_restore_and_psql():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'docker',
@@ -1393,6 +1528,7 @@ def test_restore_data_source_dump_runs_non_default_pg_restore_and_psql():
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1411,6 +1547,7 @@ def test_restore_data_source_dump_runs_non_default_pg_restore_and_psql():
             'ANALYZE',
         ),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1465,6 +1602,7 @@ def test_restore_data_source_dump_without_extract_process_restores_from_disk():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('/dump/path')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -1480,6 +1618,7 @@ def test_restore_data_source_dump_without_extract_process_restores_from_disk():
         output_log_level=logging.DEBUG,
         input_file=None,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1493,6 +1632,7 @@ def test_restore_data_source_dump_without_extract_process_restores_from_disk():
             'ANALYZE',
         ),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
@@ -1520,6 +1660,7 @@ def test_restore_data_source_dump_with_schemas_restores_schemas():
     flexmock(module).should_receive('make_environment').and_return({'PGSSLMODE': 'disable'})
     flexmock(module).should_receive('make_dump_path')
     flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('/dump/path')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         (
             'pg_restore',
@@ -1539,6 +1680,7 @@ def test_restore_data_source_dump_with_schemas_restores_schemas():
         output_log_level=logging.DEBUG,
         input_file=None,
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
     flexmock(module).should_receive('execute_command').with_args(
         (
@@ -1552,6 +1694,7 @@ def test_restore_data_source_dump_with_schemas_restores_schemas():
             'ANALYZE',
         ),
         environment={'PGSSLMODE': 'disable'},
+        working_directory=None,
     ).once()
 
     module.restore_data_source_dump(
